@@ -152,6 +152,17 @@ If you don't supply one of these forms, we assume you are specifying the date yo
 
 Returns offset of time (in secs)
 
+=head2 randchars
+
+    $rand = randchars( $n ); # default chars collection: 0..9,'a'..'z','A'..'Z'
+    $rand = randchars( $n, \@collection ); # Defined chars collection
+
+Returns random sequence of casual characters by the amount of n
+
+For example:
+
+    $rand = randchars( 8, [qw/a b c d e f/]); # -> cdeccfdf
+
 =head1 HISTORY
 
 See C<Changes> file
@@ -181,7 +192,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Carp;
 use Term::ANSIColor qw/colored/;
@@ -203,6 +214,7 @@ our @EXPORT_OK = (qw/
         dformat
         md5sum
         json_load json_save
+        randchars
         color
     /, @EXPORT);
 
@@ -360,6 +372,15 @@ sub dformat {
     $f =~ s/\[([A-Z0-9_\-.]+?)\]/(defined($d->{$1}) ? $d->{$1} : "[$1]")/eg;
     return $f;
 }
+sub randchars {
+    my $l = shift || return '';
+    return '' unless $l =~/^\d+$/;
+    my $arr = shift;
+    my $r = '';
+    my @chars = ($arr && ref($arr) eq 'ARRAY') ? (@$arr) : (0..9,'a'..'z','A'..'Z');
+    $r .= $chars[(int(rand($#chars+1)))] for (1..$l);
+    return $r;
+}
 
 # Colored helper function
 sub color {
